[tor-commits] [tor/master] control: Refactor HS_DESC events functions to not be v2 specific

nickm at torproject.org nickm at torproject.org
Wed Dec 6 00:44:53 UTC 2017


commit 242ddc85c874cafdc3513725f9357028b72eb9f8
Author: David Goulet <dgoulet at torproject.org>
Date:   Fri Nov 10 09:08:05 2017 -0500

    control: Refactor HS_DESC events functions to not be v2 specific
    
    This is a naming refactor mostly _except_ for a the events' function that take
    a rend_data_t which will require much more refactoring.
    
    No behavior change at this commit, cleanup and renaming stuff to not be only
    v2 specific.
    
    Signed-off-by: David Goulet <dgoulet at torproject.org>
---
 src/or/control.c    | 63 +++++++++++++++++++----------------------------------
 src/or/control.h    | 15 +++++++------
 src/or/rendclient.c |  3 ++-
 src/test/test_hs.c  |  3 ++-
 4 files changed, 35 insertions(+), 49 deletions(-)

diff --git a/src/or/control.h b/src/or/control.h
index 74601b978..45fc4a9bc 100644
--- a/src/or/control.h
+++ b/src/or/control.h
@@ -115,14 +115,15 @@ void control_event_transport_launched(const char *mode,
                                       tor_addr_t *addr, uint16_t port);
 const char *rend_auth_type_to_string(rend_auth_type_t auth_type);
 MOCK_DECL(const char *, node_describe_longname_by_id,(const char *id_digest));
-void control_event_hs_descriptor_requested(const rend_data_t *rend_query,
-                                           const char *desc_id_base32,
-                                           const char *hs_dir);
-void control_event_hs_descriptor_created(const char *service_id,
-                                         const char *desc_id_base32,
+void control_event_hs_descriptor_requested(const char *onion_address,
+                                           rend_auth_type_t auth_type,
+                                           const char *id_digest,
+                                           const char *desc_id);
+void control_event_hs_descriptor_created(const char *onion_address,
+                                         const char *desc_id,
                                          int replica);
-void control_event_hs_descriptor_upload(const char *service_id,
-                                        const char *desc_id_base32,
+void control_event_hs_descriptor_upload(const char *onion_address,
+                                        const char *desc_id,
                                         const char *hs_dir);
 void control_event_hs_descriptor_receive_end(const char *action,
                                              const char *onion_address,
diff --git a/src/or/rendclient.c b/src/or/rendclient.c
index 327481924..32a285457 100644
--- a/src/or/rendclient.c
+++ b/src/or/rendclient.c
@@ -515,7 +515,8 @@ directory_get_from_hs_dir(const char *desc_id,
            (rend_data->auth_type == REND_NO_AUTH ? "[none]" :
             escaped_safe_str_client(descriptor_cookie_base64)),
            routerstatus_describe(hs_dir));
-  control_event_hs_descriptor_requested(rend_query,
+  control_event_hs_descriptor_requested(rend_data->onion_address,
+                                        rend_data->auth_type,
                                         hs_dir->identity_digest,
                                         desc_id_base32);
   return 1;
diff --git a/src/test/test_hs.c b/src/test/test_hs.c
index 7737499f5..7f9eab911 100644
--- a/src/test/test_hs.c
+++ b/src/test/test_hs.c
@@ -258,7 +258,8 @@ test_hs_desc_event(void *arg)
             sizeof(desc_id_base32));
 
   /* test request event */
-  control_event_hs_descriptor_requested(&rend_query.base_, HSDIR_EXIST_ID,
+  control_event_hs_descriptor_requested(rend_query.onion_address,
+                                        rend_query.auth_type, HSDIR_EXIST_ID,
                                         STR_DESC_ID_BASE32);
   expected_msg = "650 HS_DESC REQUESTED "STR_HS_ADDR" NO_AUTH "\
                   STR_HSDIR_EXIST_LONGNAME " " STR_DESC_ID_BASE32 "\r\n";





More information about the tor-commits mailing list
diff --git a/src/or/control.c b/src/or/control.c
index d9102894e..9a8d1f302 100644
--- a/src/or/control.c
+++ b/src/or/control.c
@@ -7177,25 +7177,21 @@ rend_hsaddress_str_or_unknown(const char *onion_address)
  * <b>desc_id_base32</b> is the ID of requested hs descriptor.
  */
 void
-control_event_hs_descriptor_requested(const rend_data_t *rend_query,
+control_event_hs_descriptor_requested(const char *onion_address,
+                                      rend_auth_type_t auth_type,
                                       const char *id_digest,
-                                      const char *desc_id_base32)
+                                      const char *desc_id)
 {
-  if (!id_digest || !rend_query || !desc_id_base32) {
-    log_warn(LD_BUG, "Called with rend_query==%p, "
-             "id_digest==%p, desc_id_base32==%p",
-             rend_query, id_digest, desc_id_base32);
+  if (BUG(!id_digest || !desc_id)) {
     return;
   }
 
   send_control_event(EVENT_HS_DESC,
                      "650 HS_DESC REQUESTED %s %s %s %s\r\n",
-                     rend_hsaddress_str_or_unknown(
-                          rend_data_get_address(rend_query)),
-                     rend_auth_type_to_string(
-                          TO_REND_DATA_V2(rend_query)->auth_type),
+                     rend_hsaddress_str_or_unknown(onion_address),
+                     rend_auth_type_to_string(auth_type),
                      node_describe_longname_by_id(id_digest),
-                     desc_id_base32);
+                     desc_id);
 }
 
 /** For an HS descriptor query <b>rend_data</b>, using the
@@ -7244,52 +7240,45 @@ get_desc_id_from_query(const rend_data_t *rend_data, const char *hsdir_fp)
 
 /** send HS_DESC CREATED event when a local service generates a descriptor.
  *
  * <b>service_id</b> is the descriptor onion address.
  * <b>desc_id_base32</b> is the descriptor ID.
  * <b>replica</b> is the the descriptor replica number.
  */
 void
-control_event_hs_descriptor_created(const char *service_id,
-                                    const char *desc_id_base32,
+control_event_hs_descriptor_created(const char *onion_address,
+                                    const char *desc_id,
                                     int replica)
 {
-  if (!service_id || !desc_id_base32) {
-    log_warn(LD_BUG, "Called with service_digest==%p, "
-             "desc_id_base32==%p", service_id, desc_id_base32);
+  if (BUG(!onion_address || !desc_id)) {
     return;
   }
 
   send_control_event(EVENT_HS_DESC,
                      "650 HS_DESC CREATED %s UNKNOWN UNKNOWN %s "
                      "REPLICA=%d\r\n",
-                     service_id,
-                     desc_id_base32,
-                     replica);
+                     onion_address, desc_id, replica);
 }
 
 /** send HS_DESC upload event.
  *
  * <b>service_id</b> is the descriptor onion address.
  * <b>hs_dir</b> is the description of contacting hs directory.
  * <b>desc_id_base32</b> is the ID of requested hs descriptor.
  */
 void
-control_event_hs_descriptor_upload(const char *service_id,
+control_event_hs_descriptor_upload(const char *onion_address,
                                    const char *id_digest,
-                                   const char *desc_id_base32)
+                                   const char *desc_id)
 {
-  if (!service_id || !id_digest || !desc_id_base32) {
-    log_warn(LD_BUG, "Called with service_digest==%p, "
-             "desc_id_base32==%p, id_digest==%p", service_id,
-             desc_id_base32, id_digest);
+  if (BUG(!onion_address || !id_digest || !desc_id)) {
     return;
   }
 
   send_control_event(EVENT_HS_DESC,
                      "650 HS_DESC UPLOAD %s UNKNOWN %s %s\r\n",
-                     service_id,
+                     onion_address,
                      node_describe_longname_by_id(id_digest),
-                     desc_id_base32);
+                     desc_id);
 }
 
 /** send HS_DESC event after got response from hs directory.
@@ -7362,9 +7351,7 @@ control_event_hs_descriptor_upload_end(const char *action,
 {
   char *reason_field = NULL;
 
-  if (!action || !id_digest) {
-    log_warn(LD_BUG, "Called with action==%p, id_digest==%p", action,
-             id_digest);
+  if (BUG(!action || !id_digest)) {
     return;
   }
 
@@ -7408,9 +7395,7 @@ void
 control_event_hs_descriptor_uploaded(const char *id_digest,
                                      const char *onion_address)
 {
-  if (!id_digest) {
-    log_warn(LD_BUG, "Called with id_digest==%p",
-             id_digest);
+  if (BUG(!id_digest)) {
     return;
   }
 
@@ -7484,9 +7469,7 @@ control_event_hs_descriptor_upload_failed(const char *id_digest,
                                           const char *onion_address,
                                           const char *reason)
 {
-  if (!id_digest) {
-    log_warn(LD_BUG, "Called with id_digest==%p",
-             id_digest);
+  if (BUG(!id_digest)) {
     return;
   }
   control_event_hs_descriptor_upload_end("FAILED", onion_address,
@@ -7244,52 +7240,45 @@ get_desc_id_from_query(const rend_data_t *rend_data, const char *hsdir_fp)
 /** send HS_DESC CREATED event when a local service generates a descriptor.
  *
- * <b>service_id</b> is the descriptor onion address.
- * <b>desc_id_base32</b> is the descriptor ID.
+ * <b>onion_address</b> is service address.
+ * <b>desc_id</b> is the descriptor ID.
  * <b>replica</b> is the the descriptor replica number.
  */
@@ -7244,52 +7240,45 @@ get_desc_id_from_query(const rend_data_t *rend_data, const char *hsdir_fp)
 /** send HS_DESC upload event.
  *
- * <b>service_id</b> is the descriptor onion address.
+ * <b>onion_address</b> is service address.
  * <b>hs_dir</b> is the description of contacting hs directory.
@@ -7244,52 +7240,45 @@ get_desc_id_from_query(const rend_data_t *rend_data, const char *hsdir_fp)
  * <b>hs_dir</b> is the description of contacting hs directory.
- * <b>desc_id_base32</b> is the ID of requested hs descriptor.
+ * <b>desc_id</b> is the ID of requested hs descriptor.
  */
 void